@@ -1,5 +1,5 @@
 
-#define DEBUG_ALLOC 0
+#undef DEBUG_ALLOC
 
 #define HAVE_ATTRIBUTE 1
 
