@@ -238,7 +238,9 @@ int io_iter(struct io_backend *b)
 					WRITE_FD(fd);
 				else {
 					verbose("io_iter(): POLLHUP on inactive fd!\n");
-					close_fd(fd, CLOSE_EOF);
+					
+					/* we have no chance to flush if POLLHUP was received, therefore closekill immediately */
+					closekill_fd(fd, CLOSE_EOF);
 				}
 				continue;
 			}
